import React from 'react';
import { Button, Card, Form } from 'antd';
import { useSearchParams, useNavigate } from "react-router-dom";
import useBool from '@/utils/hooks/useBool';
import Page from './index';

const FormItem = Form.Item;
const formItemLayout = { labelCol: { span: 6 }, wrapperCol: { span: 14 } };

export default (props) => {
  /**
   * request 编辑或者新增接口
   * dataFunc 将 form 表单数据转换为接口需要格式, 一般情况下不需要这个操作
   * formDataFunc 将接口返回的值转换为 form 表单数据格式, 一般情况下不需要这个操作
   * width form 表单宽度, 默认 800px
   */
  const { request, dataFunc, formDataFunc, width = '800px', onFinish, ...leftProps } = props;
  const [loading, startLoading, stopLoading] = useBool();
  const [form] = Form.useForm();
  const navigate = useNavigate();

  // 获取 id query 参数, 如果存在说明是编辑，而不是新增
  const [params] = useSearchParams();
  const id = params.get("id");
  
  const navBack = React.useCallback(() => {
    const t = setTimeout(() => {
      navigate(-1);
      clearTimeout(t);
    }, 600);
  }, [navigate]);

  // 表单提交
  const onSubmit = (values) => {    
    startLoading();
    // 可能需要转换下格式
    const data = dataFunc ? dataFunc(id, values) : values;
    if (id) {
      request.update(id, data).then((res) => {
        stopLoading();
        if (onFinish) {
          onFinish(res);
        } else {
          navBack();
        }
      }).catch(stopLoading);
    } else {
      request.save(data)
        .then((res) => {
          stopLoading();
          if (onFinish) {
            onFinish(res);
          } else {
            navBack();
          }
        }).catch(stopLoading);
    }
  }

  // 查询详情
  React.useEffect(() => {
    if (id && request) {
      request.get(id).then(res => {
        // 此处可能需要转换下数据格式
        const formData = formDataFunc ? formDataFunc(res) : res;
        form.setFieldsValue(formData);
      })
    }
  }, [request, id]);

  return (
    <Page>
      <Card bodyStyle={{padding: '48px 24px'}}>
        <Form {...formItemLayout} form={form} onFinish={onSubmit} style={{width}} {...leftProps} >
          {props.children}
          <FormItem label=" " colon={false} style={{marginBottom: 0}}>
            <Button type="default" onClick={() => navigate(-1)}>
              取消
            </Button>
            <Button
              type="primary"
              htmlType="submit"
              style={{ marginLeft: '4em' }}
              loading={loading}
            >
              确认
            </Button>
          </FormItem>
        </Form>
      </Card>
    </Page>
  )
}