import React, { useMemo } from "react";
import { Button, Card, Form, Input, Select } from "antd";
import useBool from "@/utils/hooks/useBool";
import { useSearchParams, useNavigate } from "react-router-dom";
import Page from "@/components/Page";
import { formItemLayout, tailFormItemLayout } from "@/utils/form";
import { postTaCustom, putTaCustom, getTaCustomById } from "@/services/taCustom";
const { Option } = Select;

export default (props) => {

  const [loading, startLoading, cancelLoading] = useBool();
  const [submiting, startSubmit, cancelSubmit] = useBool();

  const [searchParams] = useSearchParams();
  const [form] = Form.useForm();
  const navigate = useNavigate();

  const id = searchParams.get("id");

  React.useEffect(() => {
    if (id) {
      getTaCustomById(id).then((res) => {
        form.setFieldsValue(res);
      })
    }
  })

  const onFinish = (values) => {
    startSubmit();
    if (id) {
      //修改
      putTaCustom(id, values).then((res) => {
        cancelSubmit();
        navigate(-1);
      }).catch(() => {
        cancelSubmit();
      })
    } else {
      //新增
      postTaCustom(values).then((res) => {
        cancelSubmit();
        navigate(-1)
      }).catch(() => {
        cancelSubmit();
      })
    }
  }

  return (
    <Page>
      <Card loading={loading}>
        <Form
          onFinish={onFinish}
          form={form}
          {...formItemLayout}
          scrollToFirstError
          style={{ maxWidth: "1000px" }}
        >
          <Form.Item
            name="customName"
            label="客户公司"
            rules={[
              {
                required: true,
                message: "请填写公司",
              },
            ]}
          >
            <Input placeholder="请输入公司" />
          </Form.Item>
          <Form.Item
            name="dutyParagraph"
            label="客户税号"
            rules={[
              {
                required: true,
                message: "请填写税号",
              },
            ]}
          >
            <Input placeholder="请输入税号" />
          </Form.Item>
          <Form.Item name="openingBank" label="开户行">
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item name="account" label="客户账号">
            <Input placeholder="请输入" />
          </Form.Item>

          <Form.Item name="contactsName" label="联系人姓名">
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item name="contactsTitle" label="联系人头衔">
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item
            name="contactsPhone"
            label="联系人手机"
            rules={[
              {
                required: true,
                message: "请填写联系人手机",
              },
            ]}
          >
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item name="contactsEmail" label="联系人邮箱">
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item name="address" label="联系人地址">
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item {...tailFormItemLayout}>
            <Button loading={submiting} type="primary" htmlType="submit">
              保存
            </Button>
            <Button style={{ marginLeft: "2em" }} onClick={() => navigate(-1)}>
              返回
            </Button>
          </Form.Item>
        </Form>
      </Card>
    </Page>
  );
};
