import React from "react";
import { useNavigate } from "react-router-dom";
import { Button, Popconfirm, message } from "antd";
import { ProTable } from "@ant-design/pro-components";
import { queryTable } from "@/utils/request";
import { getTaCustom, deleteTaCustom } from "@/services/taCustom";
import Page from "@/components/Page";

const customList = queryTable(getTaCustom)


export default (props) => {
  const actionRef = React.useRef();
  const navigate = useNavigate();

  const handleDelete = (id) => {
    if (id) {
      deleteTaCustom(id).then((res) => {
        actionRef.current.reload();
      })
    }
  }

  const columns = [
    {
      title: "公司",
      dataIndex: "customName",
      ellipsis: true,
    },
    {
      title: "税号",
      dataIndex: "dutyParagraph",
      ellipsis: true,
      search: false,
    },
    {
      title: "开户行",
      dataIndex: "openingBank",
      ellipsis: true,
    },
    {
      title: "账号",
      dataIndex: "account",
      ellipsis: true,
    },
    {
      title: "联系人姓名",
      dataIndex: "contactsName",
      ellipsis: true,
    },
    {
      title: "联系人头衔",
      dataIndex: "contactsTitle",
      search: false,
      ellipsis: true,
    },
    {
      title: "联系人手机",
      dataIndex: "contactsPhone",
      ellipsis: true,
    },
    {
      title: "联系人邮箱",
      dataIndex: "contactsEmail",
      search: false,
      ellipsis: true,
    },
    {
      title: "联系人地址",
      dataIndex: "address",
      ellipsis: true,
    },
    {
      title: "操作",
      valueType: "option",
      width: 200,
      render: (_, record) => [
        <Button
          key={3}
          style={{ padding: 0 }}
          type="link"
          onClick={() => {
            navigate(`/custom/edit?id=${record.customId}`);
          }}
        >
          编辑
        </Button>,
        <Popconfirm
          key={4}
          title="您是否确认删除 ?"
          onConfirm={() => handleDelete(record.customId)}
          okText="确定"
          cancelText="取消"
        >
          <Button style={{ padding: 0 }} type="link">
            删除
          </Button>
        </Popconfirm>,
      ],
    },
  ];

  return (
    <Page>
      <ProTable
        actionRef={actionRef}
        // scroll={{ x: 1900 }}
        rowKey="customId"
        toolBarRender={() => [
          <Button
            key="1"
            type="primary"
            onClick={() => {
              navigate("/custom/edit");
            }}
          >
            新增
          </Button>,
        ]}
        request={customList}
        columns={columns}
      />
    </Page>
  );
};
