import React from 'react';
import { Button } from 'antd';
// import { qrCode, postQrCode } from "@/services/login";
import QrCode from './QrCode';
import SuccessIcon from './SuccessIcon';
import styles from './qrcode.module.less';

// 轮询
const polling = (p, delay) => {
  let t = null;
  let cancelled = false;

  const clearTicker = () => {
    if (t) {
      clearTimeout(t);
      t = null;
    }
  }

  const cancel = () => {
    cancelled = true;
    clearTimeout(t);
  };

  const fn = () => {
    p().then((done) => {
      clearTicker();

      if (!done && !cancelled) {
        t = setTimeout(fn, delay);
      }
    }).catch(() => {
      clearTicker();
    });
  }

  fn();

  return cancel;
};

export default (props) => {
  const { onSuccess, mode, appid } = props;

  // 二维码是否初始化
  const [qrInited, setQrInited] = React.useState(false);
  // 是否扫码
  const [scaned, setScaned] = React.useState(false);
  // 二维码数据
  const [qrData, setQrData] = React.useState();
  // 是否发生错误
  const [hasError, setHasError] = React.useState(false);
  // 提示信息
  const [tips, setTips] = React.useState();
  // 停止轮询控制器
  const pollingCancel = React.useRef();

  // 重新开始
  const onReset = () => {
    // 停止轮询
    if (pollingCancel.current) {
      pollingCancel.current();
    }

    setQrInited(false);
    setScaned(false);
    setHasError(false);
  }

  // 校验二维码各种状态
  // const checkQrCode = React.useCallback((qrId, params) => {
  //   return new Promise((resolve, reject) => {
  //     postQrCode(qrId, params).then(res => {
  //       // 带有 token 说明扫码登录成功
  //       if (res.token) {
  //         onSuccess(res);
  //         resolve(true);
  //         return ;
  //       } else {
  //         // state 与 stateLabels 是对应关系
  //         const { state } = res;
  //         const stateLabels = [
  //           '未扫码',
  //           '扫码成功, 请确认登录',
  //           '扫码确认',
  //           '已取消',
  //           '已删除',
  //         ]

  //         const isError = state > 2;
  //         setScaned(state == 1);
  //         setHasError(isError);
  //         setTips(stateLabels[state]);

  //         if (isError) {
  //           reject();
  //         } else {
  //           resolve();
  //         }
  //       }
  //     }).catch((err) => {
  //       console.error(err);
  //       setTips(err.data.msg || err.message || err);

  //       setScaned(false);
  //       setHasError(true);
  //       reject();
  //     });
  //   });
  // }, []);

  // 请求二维码
  // React.useEffect(() => {
  //   if (!qrInited) {
  //     qrCode({ client: appid || "authcenter" }).then(res => {
  //       setQrData(res);
  //       setQrInited(true);

  //       // 开启轮询
  //       const fn = () => checkQrCode(res.id, { mode });
  //       pollingCancel.current = polling(fn, 1000);
  //     })
  //   }
  // }, [qrInited, mode]);

  return (
    <div className={styles['qr-form']}>
      <div className={styles['qr-form-wrapper']}>

        <div className={styles['qr-box']}>
          <QrCode text={qrData?.qrCode} />
        </div>

        {
          (scaned || hasError) && (
            <div className={styles['status-box']}>
              <div>
                {
                  scaned && !hasError && <SuccessIcon />
                }
                <div className={styles['status-tip']}>{tips}</div>
                <Button type='link' onClick={onReset}>点击刷新</Button>
              </div>
            </div>
          )
        }

      </div>

      <div className={styles['tip-box']}>
        {
          qrInited && !hasError && (
            <div>请使用行信扫码登录</div>
          )
        }
      </div>
    </div>
  )
}
