import React, { useMemo } from "react";
import { Button, Card, Form, DatePicker, Input, Select } from "antd";
import useBool from "@/utils/hooks/useBool";
import { useSearchParams, useNavigate } from "react-router-dom";
import Page from "@/components/Page";
import { formItemLayout, tailFormItemLayout } from "@/utils/form";
import { postTaProject, putTaProject, getTaProjectById } from "@/services/project";
import { getTaCustom } from "@/services/taCustom";
import moment from 'moment'
const { Option } = Select;

export default (props) => {

  const [loading, startLoading, cancelLoading] = useBool();
  const [submiting, startSubmit, cancelSubmit] = useBool();
  const [list, setList] = React.useState([]);

  const [searchParams] = useSearchParams();
  const [form] = Form.useForm();
  const navigate = useNavigate();

  const id = searchParams.get("id");
  // const Format = format("YYYY-MM-DD HH:mm:ss") : undefined;

  React.useEffect(() => {
    if (id) {
      getTaProjectById(id).then((res) => {
        // const startTime = res.startTime ? { startTime: moment(res.startTime) } : undefined;
        // const endTime = res.endTime ? { endTime: moment(res.endTime) } : undefined;
        // form.setFieldsValue({ ...res, startTime, endTime });
        // console.log('-------res', { ...res, startTime, endTime })
        form.setFieldsValue({
          ...res, startTime: res.startTime ? moment(res.startTime) : undefined, endTime: res.endTime ? moment(res.endTime) : undefined,
          crm: res.crm ? moment(res.crm) : undefined
        });
      })
    }
    getTaCustom().then((res) => {
      setList(res.records?.map(x => ({ label: x.customName, value: x.customId })) || []);
    })
  }, [id])

  const changeDate = (val) => {
    return val.format("YYYY-MM-DD HH:mm:ss")
  }

  const onFinish = (values) => {
    const startTime = values.startTime ? changeDate(values.startTime) : undefined;
    const endTime = values.endTime ? changeDate(values.endTime) : undefined;
    const crm = values.crm ? changeDate(values.crm) : undefined;

    startSubmit();
    if (id) {

      //更新
      putTaProject(id, { ...values, startTime, endTime, crm }).then((res) => {
        cancelSubmit();
        navigate(-1)
      }).catch(() => {
        cancelSubmit();
      })
    } else {
      //新增
      postTaProject({ ...values, startTime, endTime, crm }).then((res) => {
        cancelSubmit();
        navigate(-1)
      }).catch(() => {
        cancelSubmit();
      })
    }
  }

  return (
    <Page>
      <Card loading={loading}>
        <Form
          onFinish={onFinish}
          form={form}
          {...formItemLayout}
          scrollToFirstError
          style={{ maxWidth: "1000px" }}
        >
          <Form.Item
            name="projectName"
            label="项目名称"
            rules={[
              {
                required: true,
                message: "请填写项目名称",
              },
            ]}
          >
            <Input placeholder="请输入项目名称" />
          </Form.Item>
          <Form.Item name="introduction" label="项目简介">
            <Input placeholder="请输入简介" />
          </Form.Item>
          <Form.Item name="startTime" label="项目开始日期">
            <DatePicker placeholder="请选择" style={{ width: '100%' }} locale />
          </Form.Item>
          <Form.Item name="endTime" label="项目结束日期">
            <DatePicker placeholder="请选择" style={{ width: '100%' }} locale />
          </Form.Item>
          <Form.Item name="crm" label="运维服务期">
            <DatePicker placeholder="请选择" style={{ width: '100%' }} locale />
          </Form.Item>

          <Form.Item
            name="customId"
            label="所属客户"
            rules={[
              {
                required: true,
                message: "请填写所属客户",
              },
            ]}
          >
            <Select placeholder="请选择" options={list} />
            {/* {
                list.map((res, index) => {
                  return (
                    <Option key={index} value={res.customId}>{res.customName}</Option>
                  )
                })
              }
            </Select> */}
          </Form.Item>
          <Form.Item name="quotation" label="合同报价">
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item name="stage" label="目前阶段">
            <Select>
              <Select.Option value={0}>未开始</Select.Option>
              <Select.Option value={1}>处理中</Select.Option>
              <Select.Option value={2}>已完成</Select.Option>
            </Select>
          </Form.Item>
          <Form.Item
            name="contactsName"
            label="联系人姓名"
            rules={[
              {
                required: true,
                message: "请填写联系人姓名",
              },
            ]}
          >
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item name="contactsTitle" label="联系人头衔">
            <Input placeholder="请输入" />
          </Form.Item>

          <Form.Item
            name="contactsPhone"
            label="联系人手机"
            rules={[
              {
                required: true,
                message: "请填写联系人手机",
              },
            ]}
          >
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item name="contactsEmail" label="联系人邮箱">
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item name="headPerson" label="项目负责人">
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item name="serviceIsp" label="服务运营商">
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item name="hostMachine" label="项目主机">
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item name="dataBase" label="数据库">
            <Input placeholder="请输入" />
          </Form.Item>

          <Form.Item name="oss" label="项目OSS">
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item name="webUrl" label="前端地址">
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item
            name="account"
            label="项目账户"
            rules={[
              {
                required: true,
                message: "请填写账户",
              },
            ]}
          >
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item
            name="password"
            label="项目密码"
            rules={[
              {
                required: true,
                message: "请填写密码",
              },
            ]}
          >
            <Input placeholder="请输入" />
          </Form.Item>


          <Form.Item {...tailFormItemLayout}>
            <Button loading={submiting} type="primary" htmlType="submit">
              保存
            </Button>
            <Button style={{ marginLeft: "2em" }} onClick={() => navigate(-1)}>
              返回
            </Button>
          </Form.Item>
        </Form>
      </Card>
    </Page>
  );
};
