import React from "react";
import { useNavigate } from "react-router-dom";
import { Button, Popconfirm } from "antd";
import List from "@/components/Page/List";
import { queryDict } from "@/utils/request";
import { getTaCustom } from "@/services/taCustom";
import { getTaProject, deleteTaProject } from "@/services/project";

const TaCustom = queryDict(getTaCustom, { labelKey: 'customName', valueKey: 'customId' })

export default (props) => {
  const actionRef = React.useRef();
  const navigate = useNavigate();

  const columns = [
    {
      title: "项目名称",
      dataIndex: "projectName",
      ellipsis: true,
    },
    {
      title: "简介",
      dataIndex: "introduction",
      search: false,
      ellipsis: true,
    },
    {
      title: "项目开始日期",
      search: false,
      dataIndex: "startTime",
      ellipsis: true,
    },
    {
      title: "项目结束日期",
      dataIndex: "endTime",
      search: false,
      ellipsis: true,
    },
    {
      title: "运维服务期",
      dataIndex: "crm",
      search: false,
      ellipsis: true,
    },
    {
      title: "所属客户",
      dataIndex: "customId",
      valueType: "select",
      request: TaCustom,
      ellipsis: true,
    },
    {
      title: "合同报价",
      dataIndex: "quotation",
      search: false,
      ellipsis: true,
    },
    {
      title: "目前阶段",
      dataIndex: "stage",
      valueType: "select",
      valueEnum: {
        0: "未开始",
        1: "处理中",
        2: "已完成",
      }
    },
    {
      title: "联系人姓名",
      dataIndex: "contactsName",
      ellipsis: true,
    },
    {
      title: "联系人头衔",
      dataIndex: "contactsTitle",
      ellipsis: true,
    },

    {
      title: "联系人手机",
      dataIndex: "contactsPhone",
      search: false,
      ellipsis: true,
    },
    {
      title: "联系人邮箱",
      dataIndex: "contactsEmail",
      search: false,
      ellipsis: true,
    },
    {
      title: "负责人",
      dataIndex: "headPerson",
      ellipsis: true,
    },
    {
      title: "服务运营商",
      dataIndex: "serviceIsp",
      ellipsis: true,
    },

    {
      title: "主机",
      dataIndex: "hostMachine",
      search: false,
      ellipsis: true,
    },
    {
      title: "数据库",
      dataIndex: "dataBase",
      ellipsis: true,
    },
    {
      title: "OSS",
      dataIndex: "oss",
      search: false,
      ellipsis: true,
    },
    {
      title: "前端地址",
      dataIndex: "webUrl",
      search: false,
      ellipsis: true,
    },

    {
      title: "账户",
      dataIndex: "account",
      search: false,
      ellipsis: true,
    },
    {
      title: "密码",
      dataIndex: "password",
      render: (_, row) => row?.password.replace(row.password, '******'),
      search: false,
      ellipsis: true,
    },
  ];

  const onAdd = () => {
    navigate(`/project/Edit`);
  }

  const onDelete = (row) => {
    deleteTaProject(row.projectId).then(() => {
      actionRef.current.reload();
    })
  }

  const onEdit = (row) => {
    navigate(`/project/Edit?id=${row.projectId}`);
  }

  return (
    <List
      actionRef={actionRef}
      rowKey="projectId"
      scroll={{ x: 3000 }}
      columns={columns}
      onAdd={onAdd}
      onDelete={onDelete}
      onEdit={onEdit}
      request={getTaProject}
      columnOptionRender={(_, res, index) => [
        <Button key={res.projectId} style={{ padding: 0 }} type="link" href={res.webUrl}>
          跳转
        </Button>
      ]}
    />
  );
};
