import React from 'react';

import { Card, Checkbox, Button, Space } from 'antd';
import { getSysApp } from "@/services/sysapp";
import useBool from "@/utils/hooks/useBool";
import { getSysUserRole } from "@/services/sysuserrole";
import { getRoleResource, postSysRoleResource } from "@/services/sysroleresource";

export default (props) => {
  const { role } = props;

  const [values, setValues] = React.useState([]);
  const [appList, setAppList] = React.useState([]);

  const title = role ? `${role.name} - 授权应用` : "未选角色 - 授权应用";
  const [loading, startLoading, cancelLoading] = useBool();

  React.useEffect(() => {
    getSysApp({ pageSize: 500 })
      .then((res = []) => {
        setAppList(res?.records);
      })
  }, [])

  const onSubmit = () => {
    // 如果一个都不选，代表清空授权
    const roleId = role.roleId;

    const data = values.map(x => ({
      resourceId: x,
      roleId,
    }));

    startLoading();
    postSysRoleResource({ roleId }, data)
      .then((res) => {
        cancelLoading();
      })
      .catch(() => {
        cancelLoading();
      });
  };

  React.useEffect(() => {
    //授权应用查询
    if (role?.roleId) {
      const roleId = role?.roleId;

      startLoading();
      getRoleResource({ roleId }).then((res) => {
        cancelLoading();
        setValues(res.records.map((x) => x.resourceId))
      }).catch(() => {
        cancelLoading();
      })
    }
  }, [role?.roleId])

  return (
    <Card
      loading={loading}
      title={title}
      extra={
        <Button
          type="primary"
          disabled={!role || !role.roleId}
          ghost
          onClick={onSubmit}
        >
          保存
        </Button>
      }
    >
      <Checkbox.Group value={values} onChange={setValues} disabled={!role?.roleId}>
        {
          appList.map((item) => {
            return (
              <div key={item.appId} style={{ lineHeight: '2em' }}>
                <Checkbox value={item.appId}>{item.appName}</Checkbox>
              </div>
            )
          })
        }
      </Checkbox.Group>
    </Card>
  )
}