import React from 'react';
import Curd from '@/components/Page/Curd';
import { Form, Input } from 'antd';

export default (props) => {
  const columns = [
      {
          dataIndex: 'index',
          valueType: 'indexBorder',
          width: 48,
      },
      {
          title: '标题',
          dataIndex: 'title',
          copyable: true,
          ellipsis: true,
          tip: '标题过长会自动收缩',
          formItemProps: {
              rules: [
                  {
                      required: true,
                      message: '此项为必填项',
                  },
              ],
          },
      },
      {
          disable: true,
          title: '状态',
          dataIndex: 'state',
          filters: true,
          onFilter: true,
          ellipsis: true,
          valueType: 'select',
          valueEnum: {
              all: { text: '超长'.repeat(50) },
              open: {
                  text: '未解决',
                  status: 'Error',
              },
              closed: {
                  text: '已解决',
                  status: 'Success',
                  disabled: true,
              },
              processing: {
                  text: '解决中',
                  status: 'Processing',
              },
          },
      },
      {
          disable: true,
          title: '标签',
          dataIndex: 'labels',
          search: false,
          renderFormItem: (_, { defaultRender }) => {
              return defaultRender(_);
          },
          render: (_, record) => (<Space>
          {record.labels.map(({ name, color }) => (<Tag color={color} key={name}>
              {name}
              </Tag>))}
          </Space>),
      },
      {
          title: '创建时间',
          key: 'showTime',
          dataIndex: 'created_at',
          valueType: 'date',
          sorter: true,
          hideInSearch: true,
      },
      {
          title: '创建时间',
          dataIndex: 'created_at',
          valueType: 'dateRange',
          hideInTable: true,
          search: {
              transform: (value) => {
                  return {
                      startTime: value[0],
                      endTime: value[1],
                  };
              },
          },
      },
  ];

  return (
    <Curd
      columns={columns}
      request={{
        del: () => Promise.resolve(),
        save: () => Promise.resolve(),
        update: () => Promise.resolve(),
        list: () => Promise.resolve({total: 0}),
      }}
      renderFormItems={() => (
        <>
          <Form.Item label="示例1" name="demo1">
            <Input />
          </Form.Item>
          <Form.Item label="示例2" name="demo2">
            <Input />
          </Form.Item>
          <Form.Item label="示例3" name="demo3">
            <Input />
          </Form.Item>
          <Form.Item label="示例4" name="demo4">
            <Input />
          </Form.Item>
        </>
      )}
    />
  )
}
