import React from "react";
import { useNavigate } from "react-router-dom";
import { Button, Popconfirm, message } from "antd";
import { ProTable } from "@ant-design/pro-components";
import { queryTable } from "@/utils/request";
import { getSysUser, deleteSysUser } from "@/services/sysUser";
import Page from "@/components/Page";

const sysUserList = queryTable(getSysUser)

export default (props) => {
  const actionRef = React.useRef();
  const navigate = useNavigate();

  const handleDelete = (id) => {
    deleteSysUser(id).then((res) => {
      actionRef.current.reload();
    })
  }

  const columns = [
    {
      title: "姓名",
      dataIndex: "userName",
      ellipsis: true,
    },
    {
      title: "电话",
      dataIndex: "phone",
      ellipsis: true,
    },
    {
      title: "账户",
      dataIndex: "account",
      ellipsis: true,
    },
    {
      title: "密码",
      dataIndex: "password",
      ellipsis: true,
      search: false,
      render: (_, row) => row?.password.replace(row.password, '******'),
    },
    {
      title: "操作",
      valueType: "option",
      width: 200,
      render: (_, record) => [
        <Button
          key={3}
          style={{ padding: 0 }}
          type="link"
          onClick={() => {
            navigate(`/user/edit?id=${record.userId}`);
          }}
        >
          编辑
        </Button>,
        <Popconfirm
          key={4}
          title="您是否确认删除 ?"
          onConfirm={() => handleDelete(record.userId)}
          okText="确定"
          cancelText="取消"
        >
          <Button style={{ padding: 0 }} type="link">
            删除
          </Button>
        </Popconfirm>,
      ],
    },
  ];

  return (
    <Page>
      <ProTable
        actionRef={actionRef}
        rowKey="userId"
        toolBarRender={() => [
          <Button
            key="1"
            type="primary"
            onClick={() => {
              navigate("/user/edit");
            }}
          >
            新增
          </Button>,
        ]}
        request={sysUserList}
        columns={columns}
      />
    </Page>
  );
};
