import {
  UserOutlined,
  SolutionOutlined,
  FileTextOutlined,
} from "@ant-design/icons";
import { Outlet, Navigate } from "react-router-dom";
import AuthLayout from "@/layouts/AuthLayout";
import Login from "@/pages/login";
import Page404 from "@/pages/404";
import Custom from "@/pages/custom";
import CustomEdit from "@/pages/custom/Edit";
import Project from "@/pages/project";
import ProjectEdit from "@/pages/project/Edit";
import User from "@/pages/user";
import UserEdit from "@/pages/user/Edit";
/**
 * meta 用来扩展自定义数据数据
 * {
 *    title: 用于页面或者菜单的标题, 没有此字段, 菜单不会显示
 *    hideInMenu: 布尔值, 如果为 false, 菜单不会显示
 *    noLayout: 布尔值, 如果为 true, 将不会使用默认布局
 *    noSiderBar: 布尔值, 如果为 true, 将没有左侧菜单栏
 *    noFooter: 布尔值, 如果为 true, 将没有底部 footer
 *    target: 字符串, 如果为 _blank, 将在新窗口打开
 *    permission: 对应服务器端权限名称
 * }
 */

export const authRoutes = [
  {
    index: true,
    element: <Navigate to="/custom" replace={true} />,
  },
  {
    path: "custom",
    element: <Custom />,
    meta: {
      title: "客户管理",
      icon: <SolutionOutlined />,
    },
  },
  {
    path: "custom/edit",
    element: <CustomEdit />,
    meta: {
      title: "客户维护",
      hideInMenu: true,
    },
  },
  {
    path: "project",
    element: <Project />,
    meta: {
      title: "项目管理",
      icon: <FileTextOutlined />,
    },
  },
  {
    path: "project/edit",
    element: <ProjectEdit />,
    meta: {
      title: "项目维护",
      hideInMenu: true,
    },
  },
  {
    path: "user",
    element: <User />,
    meta: {
      title: "人员管理",
      icon: <UserOutlined />,
    },
  },
  {
    path: "user/edit",
    element: <UserEdit />,
    meta: {
      title: "人员维护",
      hideInMenu: true,
    },
  },
];

export const defaultRoutes = [
  {
    path: "/",
    element: <AuthLayout />,
    children: [
      {
        path: "*",
        element: <Page404 />,
      },
    ],
  },
  {
    path: "/login",
    element: <Login />,
  },
  {
    path: "*",
    element: <Page404 />,
  },
];

export function mergeAuthRoutes (r1, r2) {
  const r = r1.slice();
  const children = r1[0].children.slice();
  r[0].children = children.concat(r2);
  console.log(r)
  return r;
}

// 全部路由
export const routes = mergeAuthRoutes(defaultRoutes, authRoutes);
function getPath (parent = "/", current = "") {
  if (current.indexOf("/") === 0 || current.indexOf("http") === 0)
    return current;
  return `${parent}/${current}`.replace(/\/\//g, "/");
}

// 路由数组, 一维数组
export const routeArr = (() => {
  const flatten = (routes, parentPath = "/") => {
    return routes.reduce((acc, route) => {
      const path = getPath(parentPath, route.path);
      const children = route.children ? flatten(route.children, path) : [];

      return acc.concat([{ ...route, path }].concat(children));
    }, []);
  };

  return flatten(routes);
})();
