import { useState, useRef } from "react";
import { defaultRoutes, authRoutes, mergeAuthRoutes } from "@/routes/routes";
import { getMenuItems } from "@/routes/menus";
import { currentUser } from "@/services/login";
import { getAuthedRoutes } from "@/routes/permissions";

export default function useUser() {
  const [user, setUser] = useState(null);
  const menusRef = useRef();
  const routesRef = useRef();

  const getCurrentUser = () =>
    new Promise((resolve, reject) => {
      currentUser()
        .then((res) => {
          console.log(res);
          // authRoutes 是所有待验证授权的路由
          // authedRoutes 是已经被授权的路由
          const authedRoutes = getAuthedRoutes(authRoutes, []);

          menusRef.current = getMenuItems(authedRoutes);
          routesRef.current = mergeAuthRoutes(defaultRoutes, authedRoutes);

          setUser(res);
          resolve();
        })
        .catch(reject);
    });

  return {
    user,
    setUser,
    getCurrentUser,
    menus: menusRef.current || [],
    routes: routesRef.current || [],
  };
}
