import { getToken, setToken } from "./token";

/**
 * 异或加密, 可同时进行加密及解密
 * @param {*} src 原始数据或待解密数据
 * @param {*} key 密钥数组
 * @returns 
 */
function xorDecrypt(src, key) {
  let output = '';
  for (var i = 0; i < src.length; i++) {
    const c = src[i].charCodeAt();
    const k = key[i % key.length];
    output += String.fromCharCode(c ^ k);
  }
  return output;
}

/**
 * 获取 token
 * @param {*} url 
 * @returns 
 */
function getTokenFromUrl(url) {
  const matches = url.match(/sso-token=([^/&?]+)/);
  return matches?.[1];
}

/**
 * 初始化 token
 * @returns 
 */
export function initTokenIfExists() {
  // token 是 base64 格式
  const base64Str = getTokenFromUrl(window.location.href);
  if (!base64Str) return;

  // base64 解码
  const tkMixStr = window.atob(base64Str);
  if (!tkMixStr) return;

  // 解码后的格式为 xxxx-xxxxxxxxx
  // 其中第一部分为密钥, 第二部分为 加密字串
  const [keyStr, ...tkArr] = tkMixStr.split('-')
  if (!keyStr || !tkArr.length) return;
  
  // 需要异或解密的是第二部分
  const tkStr = tkArr.join('-');
  const tk = xorDecrypt(tkStr, keyStr.split(''))
  if (tk) {
    setToken(tk);
  }
}

/**
 * 获取加密且可用于 URL 的 token
 * @returns 
 */
export function getEncryptToken() {
  const tk = getToken();
  if (!tk) return;

  const key = (new Date).valueOf();
  
  // 用 key 加密 token
  const cipherText = xorDecrypt(tk, `${key}`.split(''));
  const mixStr = [key, cipherText].join('-');

  return window.btoa(mixStr);
}
